#
# spec file for package ongres-stringprep
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global		upstream_name    stringprep
%global		upstream_version 2.2
Name:           ongres-%{upstream_name}
Version:        %(echo %{upstream_version} | sed 's/-/~/g')
Release:        4.1
Summary:        Preparation of internationalized strings
License:        BSD-2-Clause
URL:            https://github.com/ongres/%{upstream_name}
Source0:        https://github.com/ongres/%{upstream_name}/archive/%{upstream_version}/%{upstream_name}-%{upstream_version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  java-devel >= 11
BuildRequires:  maven-local
Provides:       ongres-stringprep-parent = %{upstream_version}
Obsoletes:      ongres-stringprep-parent < %{upstream_version}
Provides:       ongres-stringprep-saslprep = %{upstream_version}
Obsoletes:      ongres-stringprep-saslprep < %{upstream_version}
BuildArch:      noarch

%description
StringPrep is the preparation of internationalized strings (stringprep, RFC 3454).

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}

%prep
%autosetup -n %{upstream_name}-%{upstream_version}
find \( -name '*.jar' -o -name '*.class' \) -delete

%pom_remove_dep org.junit:junit-bom parent

%pom_remove_plugin -r :maven-enforcer-plugin
%pom_remove_plugin -r :maven-javadoc-plugin

# codegenerator is only needed at build time, and has extra dependencies
%{mvn_package} com.ongres.stringprep:codegenerator __noinstall

# codegen is only needed for specific build profile that we do not use
rm -r codegen

%pom_xpath_inject 'pom:plugin[pom:artifactId="maven-jar-plugin"]/pom:configuration/pom:archive' '
<manifestEntries>
  <Multi-Release>true</Multi-Release>
</manifestEntries>
' parent

%build
%{mvn_build} -f

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE

%files javadoc -f .mfiles-javadoc
%license LICENSE

%changelog
* Tue Apr  1 2025 Michael Calmer <mc@suse.com>
- Version 2.2
  - Fix `Stringprep::getProvider` was not working on the module
    path.
  - The Profile interface now has overloaded methods with `char[]`
    versions.
  - The Java modules profiles `com.ongres.saslprep` and
    `com.ongres.nameprep` have implied readability with
    `com.ongres.stringprep`.
  - Exports the packages of the profiles in the module declaration
    to allow creating instances without the ServiceLoader lookup.
  - Introduce the annotation `@ProfileName` to declare the name of
    the profile used for ServiceLoader lookup.
  - Full rewrite of the `stringprep` implementation, this release
    is compatible with Java 8+.
  - The stringprep profiles can be created by implementing the
    `Profile` interface.
  - New module `nameprep` implementing the stringprep `Profile`.
  - Create Multi-release Modular JARs, the modules names are:
  - `com.ongres.stringprep`
  - `com.ongres.saslprep`
  - `com.ongres.nameprep`
  - Refactor of the `stringprep` implementation to make it
    extensible and modular, now this implemenation is considered
    feature-complete.
  - Change the module `saslprep` to implement the stringprep
    `Profile` interface.
  Removed: fix-dir-create.patch
- include parent and saslprep into main package
- exclude codegenerator
* Wed Feb 21 2024 Gus Kenion <gus.kenion@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Oct 26 2023 Fridrich Strba <fstrba@suse.com>
- Build with source and target levels 8
* Thu Mar  3 2022 Michael Calmer <mc@suse.com>
- ongres-stringprep 1.1 - initial package (bsc#1196693)
  (jsc#SLE-23993, jsc#SLE-23994)
  Add:
  * fix-dir-create.patch
